Learn R Programming

RobustGaSP (version 0.6.1)

dettepepel.3.data: Dette & Pepelyshev (2010) Curved Function

Description

A 3-dimensional test function.

Usage

dettepepel.3.data(x)

Arguments

x

a 3-dimensional vector specifying the location where the function is to be evaluated.

Value

A real value equal to the function value evaluated at x.

Details

For more details see Dette, H., & Pepelyshev, A. (2010). Generalized Latin hypercube design for computer experiments. Technometrics, 52(4).

References

Dette, H., & Pepelyshev, A. (2010). Generalized Latin hypercube design for computer experiments. Technometrics, 52(4).

S. Surjanovic, D. Bingham, Virtual Library of Simulation Experiments: Test Functions and Datasets, retrieved March 29, 2016, from http://www.sfu.ca/~ssurjano/detpep10curv.html.