This function computes the natural logarithm of profile likelihood of the PP GaSP model after plugging in the maximum likelihood estimator of the mean (trend) and variance parameters.
log_profile_lik_ppgasp(param, nugget, nugget_est, R0, X, zero_mean
,output,kernel_type, alpha)a vector of natural logarithm of inverse-range parameters and natural logarithm of the nugget-variance ratio parameter.
the nugget-variance ratio parameter if this parameter is fixed.
Boolean value of whether the nugget is estimated or fixed.
a List of matrix where the j-th matrix is an absolute difference matrix of the j-th input vector.
the mean basis function i.e. the trend function.
the mean basis function is zero or not.
a matrix where each row is one runs of the computer model output.
A vector of integer specifying the type of kernels of each coordinate of the input.
In each coordinate of the vector, 1 means the pow_exp kernel with roughness parameter specified in alpha; 2 means matern_3_2 kernel; 3 means matern_5_2 kernel; 5 means periodic_gauss kernel; 5 means periodic_exp kernel.
roughness parameters in the kernel functions.
The numerical value of natural logarithm of the profile likelihood.
M. Gu. and J.O. Berger (2016). Parallel partial Gaussian process emulation for computer models with massive output. Annals of Applied Statistics, 10(3), 1317-1347.
M. Gu. (2016). Robust Uncertainty Quantification and Scalable Computation for Computer Models with Massive Output. Ph.D. thesis. Duke University.