This function computes the derivative of a correlation matrix using 1-dimensional matern correlation function, with regard to the inverse range parameter.
matern_5_2_deriv(R0_i, R, beta_i)an absolute difference matrix of the i-th input vector.
the correlation matrix.
the inverse range parameter.
A matrix in which each element is the derivative of 1-dimensional matern correlation function with regard to the inverse range parameter.