The function computes the derivative of a correlation matrix parameterized by the periodic exponential correlation function, with regard to the inverse range parameter.
periodic_exp_deriv(R0_i, R, beta_i)an absolute difference matrix of the i-th input vector.
the correlation matrix.
A matrix in which each element is the derivative of periodic exponential correlation function with regard to the inverse range parameter.