This function computes the values of periodic folding of the exponential correlation function (i.e. the power expoential correlation with roughness parameter being 2).
periodic_exp_funct(d, beta_i)locations the periodic exponential correlation function are to be evaluated.
the inverse range parameter.
A matrix in which each element is the value of the periodic folding of the exponential correlation function evaluated at that location.