This function computes the values of periodic folding of the Gaussian correlation function (i.e. the power expoential correlation with roughness parameter being 2).
periodic_gauss_funct(d, beta_i)locations the periodic Gaussian correlation function are to be evaluated.
the inverse range parameter.
A matrix in which each element is the value of the periodic folding of the Gaussian correlation function evaluated at that location.