Learn R Programming

RobustGaSP (version 0.6.1)

pow_exp_deriv: The derivative of power exponential correlation function with regard to the inverse range parameter

Description

The function computes the derivative of a correlation matrix using 1-dimensional power exponential correlation function, with regard to the inverse range parameter.

Usage

pow_exp_deriv(R0_i, R, beta_i, alpha_i)

Arguments

R0_i

an absolute difference matrix of the i-th input vector.

R

the correlation matrix.

beta_i

alpha_i

the roughness parameter.

Value

A matrix in which each element is the derivative of 1-dimensional power exponential correlation function with regard to the inverse range parameter.

See Also

pow_exp_funct.