pow_exp_funct:
Pow exponential correlation function.
Description
This function computes the values of power exponential correlation function.
Usage
pow_exp_funct(d, beta_i, alpha_i)
Arguments
d
locations the power exponential correlation function are to be evaluated.
beta_i
the inverse range parameter.
Value
A matrix in which each element is the value of the power exponential function evaluated at that location.