Learn R Programming

RobustGaSP (version 0.6.1)

pred_rgasp: Prediction for robust GaSP model

Description

A function to make prediction on robust GaSP models after the robust GaSP model has been constructed.

Usage

pred_rgasp(beta, nu, input, X, zero_mean,output, testing_input,
           X_testing, L, LX, theta_hat, sigma2_hat, 
           q_025, q_975, r0, kernel_type, alpha,method,interval_data)

Arguments

beta

inverse-range parameters.

nu

noise-variance ratio parameter.

input

input matrix.

X

the mean basis function i.e. the trend function.

zero_mean

The mean basis function is zero or not.

output

output matrix.

testing_input

testing input matrix.

X_testing

mean/trend matrix of testing inputs.

L

a lower triangular matrix for the cholesky decomposition of R, the correlation matrix.

LX

a lower triangular matrix for the cholesky decomposition of $X^tR^-1X$.

theta_hat

estimated mean/trend parameters.

sigma2_hat

estimated variance parameter.

q_025

0.025 quantile of t distribution.

q_975

0.975 quantile of t distribution.

r0

a matrix of absolute difference between inputs and testing inputs.

kernel_type

type of kernel. matern_3_2 and matern_5_2 are Matern kernel with roughness parameter 3/2 and 5/2 respectively. pow_exp is power exponential kernel with roughness parameter alpha. If pow_exp is to be used, one needs to specify its roughness parameter alpha.

alpha

Roughness parameters in the kernel functions.

method

method of parameter estimation. post_mode means the marginal posterior mode is used for estimation. mle means the maximum likelihood estimation is used. mmle means the maximum marginal likelihood estimation is used. The post_mode is the default method.

interval_data

a boolean value. If T, the interval of the data will be calculated. If F, the interval of the mean of the data will be calculated.

Value

A list of 4 elements. The first is a vector for predictive mean for testing inputs. The second is a vector for lower quantile for 95% posterior credible interval and the third is the upper quantile for 95% posterior credible interval for these testing inputs. The last is a vector of standard deviation of each testing inputs.

References

Mengyang Gu. (2016). Robust Uncertainty Quantification and Scalable Computation for Computer Models with Massive Output. Ph.D. thesis. Duke University.

See Also

predict.rgasp