Learn R Programming

RobustGaSP (version 0.6.1)

search_LB_prob: Search for the default lower bound of range parameters.

Description

Function to find the values to construct the default lower bound of range parameters.

Usage

search_LB_prob(param, R0, COND_NUM_UB, p, kernel_type, alpha, nugget)

Arguments

param

A vector of natural logarithm of inverse-range parameters and natural logarithm of the nugget-variance ratio parameter.

R0

A List of matrix where the j-th matrix is an absolute difference matrix of the j-th input vector.

COND_NUM_UB

The maximum condition number of the correlation matrix.

p

kernel_type

Type of kernel. matern_3_2 and matern_5_2 are Matern kernel with roughness parameter 3/2 and 5/2 respectively. pow_exp is power exponential kernel with roughness parameter alpha. If pow_exp is to be used, one needs to specify its roughness parameter alpha.

alpha

Roughness parameters in the kernel functions.

nugget

The nugget-variance ratio parameter if this parameter is fixed.

Value

A vector of values used in constructing the default lower bound of range parameters.

References

Mengyang Gu. (2016). Robust Uncertainty Quantification and Scalable Computation for Computer Models with Massive Output. Ph.D. thesis. Duke University.