The function computes the derivative of a correlation matrix using 1-dimensional power exponential correlation function, with regard to the inverse range parameter.
pow_exp_deriv(R0_i, R, beta_i, alpha_i)an absolute difference matrix of the i-th input vector.
the correlation matrix.
the roughness parameter.
A matrix in which each element is the derivative of 1-dimensional power exponential correlation function with regard to the inverse range parameter.