Function to find the values to construct the default lower bound of range parameters.
search_LB_prob(param, R0, COND_NUM_UB, p, kernel_type, alpha, nugget)A vector of natural logarithm of inverse-range parameters and natural logarithm of the nugget-variance ratio parameter.
A List of matrix where the j-th matrix is an absolute difference matrix of the j-th input vector.
The maximum condition number of the correlation matrix.
Type of kernel. matern_3_2 and matern_5_2 are Matern kernel with roughness parameter 3/2 and 5/2 respectively. pow_exp is power exponential kernel with roughness parameter alpha. If pow_exp is to be used, one needs to specify its roughness parameter alpha.
Roughness parameters in the kernel functions.
The nugget-variance ratio parameter if this parameter is fixed.
A vector of values used in constructing the default lower bound of range parameters.
Mengyang Gu. (2016). Robust Uncertainty Quantification and Scalable Computation for Computer Models with Massive Output. Ph.D. thesis. Duke University.